==> haskell-text-iso8601-0.1.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-iso8601
version:              0.1.1
visibility:           public
id:                   text-iso8601-0.1.1-KqFo7N01GJ7AtgFAHcwEke
key:                  text-iso8601-0.1.1-KqFo7N01GJ7AtgFAHcwEke
license:              BSD-3-Clause
copyright:            Oleg Grenrus <oleg.grenrus@iki.fi>
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskell/aeson
synopsis:             Converting time to and from ISO 8601 text.
description:
    Converting time to and from IS0 8601 text.
    Specifically the [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) profile.

category:             Parsing
abi:                  11b0b7707396447cb5c1ca2d2b00a590
exposed:              True
exposed-modules:      Data.Time.FromText Data.Time.ToText
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-iso8601
hs-libraries:         HStext-iso8601-0.1.1-KqFo7N01GJ7AtgFAHcwEke
depends:
    base-4.17.2.1 integer-conversion-0.1.1-5bnvggFeQWDDAHG9nlytG4
    text-2.0.2 time-1.12.2 time-compat-1.9.7-6CffHFxKpSj3ygXvN1W4Qf

haddock-interfaces:
    /usr/share/doc/haskell-text-iso8601/html/text-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-text-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-iso8601-0.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-iso8601
version:              0.1.1
visibility:           public
id:                   text-iso8601-0.1.1-BMvxcOsfGYZ2u3PkpOl6sJ
key:                  text-iso8601-0.1.1-BMvxcOsfGYZ2u3PkpOl6sJ
license:              BSD-3-Clause
copyright:            Oleg Grenrus <oleg.grenrus@iki.fi>
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskell/aeson
synopsis:             Converting time to and from ISO 8601 text.
description:
    Converting time to and from IS0 8601 text.
    Specifically the [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339) profile.

category:             Parsing
abi:                  175c53abaffd77fe3218069d9f1ceba4
exposed:              True
exposed-modules:      Data.Time.FromText Data.Time.ToText
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-iso8601-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-iso8601
hs-libraries:         HStext-iso8601-0.1.1-BMvxcOsfGYZ2u3PkpOl6sJ
depends:
    base-4.17.2.1 integer-conversion-0.1.1-IChGTZqKrwL2GYpSHnNO7O
    text-2.0.2 time-1.12.2 time-compat-1.9.7-F05sjSWoRPjEQNCOQkJaS6

haddock-interfaces:
    /usr/share/doc/haskell-text-iso8601/html/text-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-text-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
